# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import transactions_filter_stream_pb2 as transactions__filter__stream__pb2


class TransactionsFilterStreamStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.subscribeToTransactionsWithProofs = channel.unary_stream(
        '/org.dash.platform.dapi.v0.TransactionsFilterStream/subscribeToTransactionsWithProofs',
        request_serializer=transactions__filter__stream__pb2.TransactionsWithProofsRequest.SerializeToString,
        response_deserializer=transactions__filter__stream__pb2.TransactionsWithProofsResponse.FromString,
        )


class TransactionsFilterStreamServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def subscribeToTransactionsWithProofs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_TransactionsFilterStreamServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'subscribeToTransactionsWithProofs': grpc.unary_stream_rpc_method_handler(
          servicer.subscribeToTransactionsWithProofs,
          request_deserializer=transactions__filter__stream__pb2.TransactionsWithProofsRequest.FromString,
          response_serializer=transactions__filter__stream__pb2.TransactionsWithProofsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'org.dash.platform.dapi.v0.TransactionsFilterStream', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
